@@ -52,7 +52,13 @@ def get_delivery_order_status_dic():
         35: "Rechazado Cliente",
         36: "Rechazado Alas",
         37: "Robada",
-        38: "Extraviada"
+        38: "Extraviada",
+        39: "Retirada",
+        40: "No Retirada",
+        41: "No Retirable",
+        42: "Viajando a CD",
+        43: "Viajando B2B",
+        44: "Entregada B2B"
     }
 
 
@@ -260,7 +266,8 @@ DELIVERY_ORDER_STATE_MACHINE = {
 
 PICKUP_ORDER_STATE_MACHINE = {
     DeliveryOrderStatusType.Planning.value: [
-        DeliveryOrderStatusType.PlanningApproved.value
+        DeliveryOrderStatusType.PlanningApproved.value,
+        DeliveryOrderStatusType.Planning.value
     ],
     DeliveryOrderStatusType.PlanningApproved.value: [
         DeliveryOrderStatusType.VirtuallyReceived.value,
@@ -322,6 +329,25 @@ PICKUP_ORDER_STATE_MACHINE = {
         DeliveryOrderStatusType.Recovered.value
     ]
 }
+
+class BulkStatusType(Enum):
+    Started = 1
+    DCReceived = 2
+    ITControlled = 3
+    SERTravelling = 4
+    Opened = 5
+    
+class BulkOperationStatusType(Enum):
+    Created = 1
+    Packaged = 2
+    Controlled = 3
+    Travelling = 4
+    Received = 5
+    
+class PackageSerReceiveStatusType(Enum):
+    Pending = 1
+    Accepted = 2
+    Damaged = 3
     
 def get_delivery_rejected_reason_dic():  
     return {
@@ -571,8 +597,8 @@ class DeliveryOrderClient(EntityClientBase):
     def delivery_courier_receive(self, id, event_info, pasync=True):
         return self.http_post_json(self.entity_endpoint_base_url + "{0}/_delivery-courier-receive".format(id), event_info)
     
-    def pickup_receive(self, id, event_info, status):
-        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_pickup-receive".format(id), {'event_info': event_info, 'status': status})
+    def pickup_receive(self, id, params):
+        return self.http_post_json(self.entity_endpoint_base_url + "{0}/_pickup-receive".format(id), params)
     # endregion
 
     def search_batch(self, search_info):
